Learn R Programming

densEstBayes (version 1.0-2.2)

OldFaithful2011: Intervals between geyser eruptions

Description

The OldFaithful2011 array has time interval between eruptions (minutes) for all 3,507 eruptions of the Old Faithful Geyser (Yellowstone National Park, U.S.A.) in the year 2011.

Usage

data(OldFaithful2011)

Arguments

Format

Each entry of the array is the time interval in minutes between each geyser eruption in chronological order.

Examples

Run this code
library(densEstBayes) ; data(OldFaithful2011) 
hist(OldFaithful2011,breaks = 25,col = "gold",
     xlab = "time interval between geyser eruptions (minutes)")
dest <- densEstBayes(OldFaithful2011,method="SMFVB")
plot(dest,xlab = "time interval between geyser eruptions (minutes)")
rug(OldFaithful2011,col = "dodgerblue",quiet = TRUE)

Run the code above in your browser using DataLab