powered by
Returns ordinates of a member of the family of Normal Mixture density functions devised in Marron and Wand (1992).
dMarronWand(x,densNum,drv)
Vector of abscissae values.
An integer between 1 and 15 that specifies the density function according to Table 1 of Marron and Wand (1992).
Either -1,0,1,2 depending on the order of the derivative required, with drv = -1 corresponding to the anti-derivative. The default value is drv = 0.
drv = -1
drv = 0
Matt P. Wand matt.wand@uts.edu.au
Marron, J.S. and Wand, M.P. (1992). Exact mean integrated squared error. The Annals of Statistics, 20, 712-736.
library(densEstBayes) xg <- seq(-3,3,length = 1001) densg <- dMarronWand(xg,8) plot(xg,densg,type = "l")
Run the code above in your browser using DataLab