powered by
Returns a random sample from a member of the family of Normal Mixture density functions devised in Marron and Wand (1992).
rMarronWand(n,densNum)
The sample size, which is a positive integer.
An integer between 1 and 15 that specifies the density function according to Table 1 of Marron and Wand (1992).
Matt P. Wand matt.wand@uts.edu.au
Marron, J.S. and Wand, M.P. (1992). Exact mean integrated squared error. The Annals of Statistics, 20, 712-736.
library(densEstBayes) x <- rMarronWand(1000,8) hist(x,breaks = 50,col = "gold") dest <- densEstBayes(x,method = "SMFVB") plot(dest) ; rug(x,col = "dodgerblue",quiet = TRUE)
Run the code above in your browser using DataLab